@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-extensions-manager-ui-extension.c,v 1.4 2005/01/28 22:29:41 chpe Exp $
+ *  $Id: ephy-extensions-manager-ui-extension.c,v 1.5 2005/04/19 11:30:17 chpe Exp $
  */
 
 #include "config.h"
@@ -58,7 +58,7 @@ typedef struct
 static void display_cb (GtkAction *action,
 			EphyWindow *window);
 
-static GtkActionEntry action_entries [] =
+static const GtkActionEntry action_entries [] =
 {
 	{ "ExtensionsManagerUI",
 	  NULL,
