@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: gestures.c,v 1.3 2005/01/13 16:15:48 chpe Exp $
+ *  $Id: gestures.c,v 1.4 2005/01/28 22:30:05 chpe Exp $
  */
 
 #include "config.h"
@@ -35,7 +35,7 @@ register_module (GTypeModule *module)
 {
 	GType extension_type;
 
-	LOG ("Registering EphyGesturesExtension")
+	LOG ("Registering EphyGesturesExtension");
 
 	ephy_gesture_register_type (module);
 
