@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-sample2-extension.c,v 1.5 2004/12/30 22:45:17 chpe Exp $
+ *  $Id: ephy-sample2-extension.c,v 1.7 2005/01/28 22:30:21 chpe Exp $
  */
 
 #include "config.h"
@@ -51,7 +51,7 @@ ephy_sample2_extension_init (EphySample2Extension *extension)
 {
 	extension->priv = EPHY_SAMPLE2_EXTENSION_GET_PRIVATE (extension);
 
-	LOG ("EphySample2Extension initialising")
+	LOG ("EphySample2Extension initialising");
 }
 
 static void
@@ -60,7 +60,7 @@ ephy_sample2_extension_finalize (GObject *object)
 /*
 	EphySample2Extension *extension = EPHY_SAMPLE2_EXTENSION (object);
 */
-	LOG ("EphySample2Extension finalising")
+	LOG ("EphySample2Extension finalising");
 
 	G_OBJECT_CLASS (parent_class)->finalize (object);
 }
@@ -73,59 +73,23 @@ dom_mouse_down_cb (EphyEmbed *embed,
 	gpointer dom_event;
 
 	dom_event = ephy_embed_event_get_dom_event (event);
-	LOG ("DOM Event %p", dom_event)
+
+	LOG ("DOM Event %p", dom_event);
 
 	mozilla_do_something (dom_event);
 
 	return FALSE;
 }
 
-static void
-tab_added_cb (GtkWidget *notebook,
-	      EphyTab *tab,
-	      EphySample2Extension *extension)
-{
-	EphyEmbed *embed;
-
-	g_return_if_fail (EPHY_IS_TAB (tab));
-
-	embed = ephy_tab_get_embed (tab);
-	g_return_if_fail (EPHY_IS_EMBED (embed));
-
-	g_signal_connect (embed, "ge_dom_mouse_down",
-			  G_CALLBACK (dom_mouse_down_cb), extension);
-}
-
-static void
-tab_removed_cb (EphyEmbed *notebook,
-		EphyTab *tab,
-		EphySample2Extension *extension)
-{
-	EphyEmbed *embed;
-
-	g_return_if_fail (EPHY_IS_TAB (tab));
-
-	embed = ephy_tab_get_embed (tab);
-	g_return_if_fail (EPHY_IS_EMBED (embed));
-
-	g_signal_handlers_disconnect_by_func
-		(embed, G_CALLBACK (dom_mouse_down_cb), extension);
-}
-
 static void
 impl_attach_window (EphyExtension *ext,
 		    EphyWindow *window)
 {
 	GtkWidget *notebook;
 
-	LOG ("EphySample2Extension attach_window")
+	LOG ("EphySample2Extension attach_window");
 
 	notebook = ephy_window_get_notebook (window);
-
-	g_signal_connect_after (notebook, "tab_added",
-				G_CALLBACK (tab_added_cb), ext);
-	g_signal_connect_after (notebook, "tab_removed",
-				G_CALLBACK (tab_removed_cb), ext);
 }
 
 static void
@@ -134,14 +98,9 @@ impl_detach_window (EphyExtension *ext,
 {
 	GtkWidget *notebook;
 
-	LOG ("EphySample2Extension detach_window")
+	LOG ("EphySample2Extension detach_window");
 
 	notebook = ephy_window_get_notebook (window);
-
-	g_signal_handlers_disconnect_by_func
-		(notebook, G_CALLBACK (tab_added_cb), ext);
-	g_signal_handlers_disconnect_by_func
-		(notebook, G_CALLBACK (tab_removed_cb), ext);
 }
 
 static void
@@ -149,7 +108,17 @@ impl_attach_tab (EphyExtension *ext,
 		 EphyWindow *window,
 		 EphyTab *tab)
 {
-	LOG ("attach_tab")
+	EphyEmbed *embed;
+
+	LOG ("impl_attach_tab");
+
+	g_return_if_fail (EPHY_IS_TAB (tab));
+
+	embed = ephy_tab_get_embed (tab);
+	g_return_if_fail (EPHY_IS_EMBED (embed));
+
+	g_signal_connect (embed, "ge_dom_mouse_down",
+			  G_CALLBACK (dom_mouse_down_cb), ext);
 }
 
 static void
@@ -157,7 +126,17 @@ impl_detach_tab (EphyExtension *ext,
 		 EphyWindow *window,
 		 EphyTab *tab)
 {
-	LOG ("detach_tab")
+	EphyEmbed *embed;
+
+	LOG ("impl_detach_tab");
+
+	g_return_if_fail (EPHY_IS_TAB (tab));
+
+	embed = ephy_tab_get_embed (tab);
+	g_return_if_fail (EPHY_IS_EMBED (embed));
+
+	g_signal_handlers_disconnect_by_func
+		(embed, G_CALLBACK (dom_mouse_down_cb), ext);
 }
 
 static void
